﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="X264View.xaml.cs" company="HandBrake Project (http://handbrake.fr)">
//   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// <summary>
//   Interaction logic for X264View.xaml
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrakeWPF.Views
{
    /// <summary>
    /// Interaction logic for AdvancedView.xaml
    /// </summary>
    public partial class X264View
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="X264View"/> class. 
        /// </summary>
        public X264View()
        {
            InitializeComponent();
        }
    }
}
